package CPAN::Test::Dummy::Perl5::DevRelease;
use strict;
use warnings;

our $VERSION = '0.002';

1;
__END__

=encoding utf-8

=head1 NAME

CPAN::Test::Dummy::Perl5::DevRelease - test dev release

=head1 SYNOPSIS

  use CPAN::Test::Dummy::Perl5::DevRelease;

=head1 DESCRIPTION

CPAN::Test::Dummy::Perl5::DevRelease is a dummy CPAN distribution
to test dev releases.

=head1 AUTHOR

Shoichi Kaji <skaji@cpan.org>

=head1 COPYRIGHT AND LICENSE

Copyright 2016 Shoichi Kaji <skaji@cpan.org>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
